:mod:`xoutil.aop.basic` - Basic AOP
====================================

.. automodule:: xoutil.aop.basic

.. autofunction:: complementor

.. autofunction:: contextualized

.. autofunction:: weaved(target, *sources, **attrs)
